@@ -1,6 +1,7 @@
 import click
 
-from hoss.version import __version__, get_server_version, ServerCheckError
+from hoss.version import __version__, get_server_version
+from hoss.error import ServerCheckError
 from hoss.console import console
 
 
