@@ -63,17 +63,18 @@ class ObjectStore(CoreAPI):
         self._client[namespace] = client
         return client
 
-    def reset_client(self, namespace: str) -> None:
-        """This method removes the boto3 client stored in this instance. This is useful when trying to use the
+    def reset_client(self) -> None:
+        """This method removes the boto3 clients stored in this instance. This is useful when trying to use the
         client lib with multiprocessing and you need to make sure each process has its own boto3 client.
 
-        Args:
-            namespace: the namespace to remove
-
         Returns:
             None
         """
-        del self._client[namespace]
+        keys = [k for k in self._client.keys()]
+        for k in keys:
+            del self._client[k]
+
+        self._client = dict()
 
     def object_exists(self, namespace: str, bucket: str, key) -> bool:
         """Check if an object exists in the object store
